Introduction - Tabler - Premium and Open Source dashboard template with responsive and high quality UI.

## Documentation

# Introduction

Tabler is a UI kit that speeds up the development process and makes it easier than ever! Built on the latest version of Bootstrap, it helps you create templates based on fully customizable and ready-to-use UI components, which can be used by both simple websites and sophisticated systems. With basic knowledge of HTML and CSS, you’ll be able to create dashboards that are fully functional and beautifully designed!

### Getting started

- - Getting Started
- - Download
- - Browser Support

### Content

- - Colors
- - Typography
- - Icons
- - Customize Tabler

### Layout

- - Page headers

### Form components

- - Form elements
- - Form helpers
- - Validation states
- - Image check
- - Color check
- - Form selectboxes
- - Form fieldset

### Components

- - Alerts
- - Avatars
- - Badges
- - Breadcrumb
- - Buttons
- - Cards
- - Carousel
- - Dropdowns
- - Divider
- - Empty states
- - Modals
- - Page headers
- - Progress
- - Range slider
- - Ribbons
- - Placeholder
- - Spinners
- - Statuses
- - Steps
- - Switch icon
- - Tables
- - Tabs
- - Timelines
- - Toasts
- - Tooltips

### Utilities

- - Borders
- - Cursors
- - Interactions

### Plugins

- - Autosize
- - Form input mask
- - Flags
- - Payments
- - Charts